==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/manage.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>



<form action="index.php?amn=grp_manage" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php if (isset($topic['topic_id'])) { echo $topic['topic_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_manage'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $group['group_title'];?></b><br />
					<?php echo $group['group_synopsis'];?><br />				
				</p>
				
				<ul>
					<li><a href="index.php?amn=grp_edit&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_edit'];?></a></li>
					<li><a href="index.php?amn=grp_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;policy=1"><?php echo $lang['href_policy'];?></a></li>
					<li><a href="index.php?amn=core_ann_edit&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_announcement'];?></a></li>
					<li><a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>&amp;add_topic=1"><?php echo $lang['href_add_topic'];?></a></li>
					<li><a href="index.php?amn=grp_poll_list&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_manage_poll'];?></a></li>
					<li><a href="index.php?amn=core_stylesheet_edit&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_stylesheet'];?></a></li>
					</ul>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_ownership'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($coordinators)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($coordinators as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_group_archive'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_group_archive'];?><br />
				</p>
				
				<hr />
					
				<p align="right">
					<input name="archive_group" type="submit" class="input_submit" value="<?php echo $lang['sub_archive_group'];?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_topics'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($topics)) {
				?>
				<table cellspacing="2" cellpadding="1" border="0" width="100%">
					<?php
					foreach ($topics as $key => $i):
					?>
					<tr>
						<td valign="top">
							<a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>"><?php echo $i['topic_title'];?></a><br />
						</td>
						<td align="right">
							<?php if (!empty($i['topic_hidden'])) { echo "(hidden)";}?><br />
						</td>
						<td align="right">
							<?php if (isset($i['topic_order'])) { echo $i['topic_order'];}?><br />
						</td>
					</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_topics'];?><br />
					</p>
				<?php }?>
			
				<?php
				if (isset($topic) || isset($_REQUEST['add_topic'])) {
				?>
				
				<hr />
				
				<p>
					<label for="id_topic_title">title</label>
					<input type="text" id="id_topic_title" name="topic_title" size="28" value="<?php if (isset($topic['topic_title'])) { echo $topic['topic_title'];}?>" class="input1" /><br />
				</p>
				
				<p>
					<label for="id_topic_synopsis">synopsis</label>
					<textarea id="id_topic_title" maxlength="255" cols="25" rows="2" name="topic_synopsis"><?php if (isset($topic['topic_synopsis'])) { echo $topic['topic_synopsis'];}?></textarea><br />
				</p>
				
				<p>
					<?php
					$checked = "";
					
					if (!empty($topic['topic_hidden'])) {
						$checked = "checked=\"checked\"";
					}			
					?>
					<label for="id_topic_hidden">hidden</label>
					<input type="checkbox" id="id_topic_hidden" name="topic_hidden" value="1" <?php echo $checked;?> /><br />
				</p>
				
				<p>
					<label for="id_topic_order"><?php echo $lang['txt_label_topic_order'];?></label>
					<input type="text" name="topic_order" size="3" value="<?php if (isset($topic['topic_order'])) { echo $topic['topic_order'];}?>" class="input1" /><br />
				</p>
				
				<p>
					<label for="id_user_id"><?php echo $lang['txt_coordinator'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						if (isset($coordinators)) {
						foreach ($coordinators as $key => $i):
						
						$selected = "";
						if ($topic['user_id'] == $i['user_id']) {
							$selected = "selected=\"selected\"";
						}
						
						?>
						<option value="<?php echo $i['user_id'];?>" <?php echo $selected;?>><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="update_topic" class="input_submit" value="<?php echo $lang['sub_update_topic'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tags'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=grp_manage&amp;group_id=" . $group['group_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="OK" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="DEL" /><br />
						</td>					
					</tr>				
				</table>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_grp_0_4.zip: am_mod_grp_0_4/components/grp/template/barnraiser_01/manage.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>



<form action="index.php?amn=grp_manage" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php if (isset($topic['topic_id'])) { echo $topic['topic_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_manage'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $group['group_title'];?></b><br />
					<?php echo $group['group_synopsis'];?><br />
				</p>
				
				<ul>
					<li><a href="index.php?amn=grp_edit&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_edit'];?></a></li>
					<li><a href="index.php?amn=grp_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;policy=1"><?php echo $lang['href_policy'];?></a></li>
					<li><a href="index.php?amn=core_ann_edit&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_announcement'];?></a></li>
					<li><a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>&amp;add_topic=1"><?php echo $lang['href_add_topic'];?></a></li>
					<li><a href="index.php?amn=grp_poll_list&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_manage_poll'];?></a></li>
					<li><a href="index.php?amn=core_stylesheet_edit&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;item_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_stylesheet'];?></a></li>
					</ul>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_ownership'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_owner_intro'];?><br />
				</p>
				
				<?php
				if (isset($coordinators)) {
				?>
				<p>
					<label for="id_user_id"><?php echo $lang['txt_new_owner'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						foreach ($coordinators as $key => $i):
						?>
						<option value="<?php echo $i['user_id'];?>"><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						?>
					</select>
				</p>
				
				<hr />
					
				<p align="right">
					<input name="update_ownership" type="submit" class="input_submit" value="<?php echo $lang['sub_resign'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_group_archive'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				
				<p>
					<?php echo $lang['txt_group_archive'];?><br />
				</p>
				
				<hr />
					
				<p align="right">
					<input name="archive_group" type="submit" class="input_submit" value="<?php echo $lang['sub_archive_group'];?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_topics'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($topics)) {
				?>
				<table cellspacing="2" cellpadding="1" border="0" width="100%">
					<?php
					foreach ($topics as $key => $i):
					?>
					<tr>
						<td valign="top">
							<a href="index.php?amn=grp_manage&amp;group_id=<?php echo $group['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>"><?php echo $i['topic_title'];?></a><br />
						</td>
						<td align="right">
							<?php if (!empty($i['topic_hidden'])) { echo "(hidden)";}?><br />
						</td>
						<td align="right">
							<?php if (isset($i['topic_order'])) { echo $i['topic_order'];}?><br />
						</td>
					</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_topics'];?><br />
					</p>
				<?php }?>
			
				<?php
				if (isset($topic) || isset($_REQUEST['add_topic'])) {
				?>
				
				<hr />
				
				<p>
					<label for="id_topic_title">title</label>
					<input type="text" id="id_topic_title" name="topic_title" size="28" value="<?php if (isset($topic['topic_title'])) { echo $topic['topic_title'];}?>" class="input1" /><br />
				</p>
				
				<p>
					<label for="id_topic_synopsis">synopsis</label>
					<textarea id="id_topic_title" maxlength="255" cols="25" rows="2" name="topic_synopsis"><?php if (isset($topic['topic_synopsis'])) { echo $topic['topic_synopsis'];}?></textarea><br />
				</p>
				
				<p>
					<?php
					$checked = "";
					
					if (!empty($topic['topic_hidden'])) {
						$checked = "checked=\"checked\"";
					}
					?>
					<label for="id_topic_hidden">hidden</label>
					<input type="checkbox" id="id_topic_hidden" name="topic_hidden" value="1" <?php echo $checked;?> /><br />
				</p>
				
				<p>
					<label for="id_topic_order"><?php echo $lang['txt_label_topic_order'];?></label>
					<input type="text" name="topic_order" size="3" value="<?php if (isset($topic['topic_order'])) { echo $topic['topic_order'];}?>" class="input1" /><br />
				</p>
				
				<p>
					<label for="id_user_id"><?php echo $lang['txt_coordinator'];?></label>
					<select id="id_user_id" name="user_id" style="width:160px;">
						<?php
						if (isset($coordinators)) {
						foreach ($coordinators as $key => $i):
						
						$selected = "";
						if ($topic['user_id'] == $i['user_id']) {
							$selected = "selected=\"selected\"";
						}
						
						?>
						<option value="<?php echo $i['user_id'];?>" <?php echo $selected;?>><?php echo $i['identity_nic'];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="update_topic" class="input_submit" value="<?php echo $lang['sub_update_topic'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_tags'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=grp_manage&amp;group_id=" . $group['group_id'] . "&amp;edit_tag=" . $i['tag_id'] . "&amp;user_id=" . $i['item_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="OK" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="DEL" /><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
</div>
</form>
